@@ -426,8 +426,8 @@ define!({
 
     pub struct KeyframeBlock {
         pub span: Span,
-        pub selector: Vec<KeyframeSelector>,
-        pub rule: KeyframeBlockRule,
+        pub prelude: Vec<KeyframeSelector>,
+        pub block: Block,
     }
 
     pub enum KeyframeSelector {
@@ -435,11 +435,6 @@ define!({
         Percent(Percent),
     }
 
-    pub enum KeyframeBlockRule {
-        Block(Box<Block>),
-        AtRule(Box<AtRule>),
-    }
-
     pub struct LayerName {
         pub span: Span,
         pub name: Vec<Ident>,
